#' eseis: Environmental Seismology Toolbox
#' 
#' The package eseis contains a growing set of function to handle the 
#' complete workflow of environmental seismology, i.e., the scientific 
#' field that studies the seismic signals that are emitted by Earth 
#' surface processes. The package suppers reading the two most common 
#' seismic data formats, general functions for preparational and 
#' analytical signal processing as well as specified functions for 
#' handling signals generated by Earth surface processes. Finally, 
#' graphical plot functions are provided, too.
#'
#' @name eseis
#' @aliases eseis
#' @docType package
#' @author Michael Dietze
#' @keywords Environmental Seismology, signal processing
#' @importFrom graphics image
#' @importFrom stats ccf spec.taper spectrum filter spec.pgram spec.ar median nextn
#' @importFrom methods as new
#' @importFrom Rcpp evalCpp
#' @importFrom IRISSeismic readMiniseedFile getNetwork getStation getSNCL
#' @importFrom grDevices colorRampPalette dev.off jpeg
#' @importFrom utils read.delim write.table read.table
#' @useDynLib eseis
NULL

#' Seismic trace of a rockfall event.
#' 
#' The dataset comprises the seismic signal (vertical component) of 
#' a rockfall event, preceeded by an earthquake. The data have been
#' recorded at 200 Hz sampling frequency with an Omnirecs Cube ext 3
#' data logger.
#' 
#' @name rockfall
#' @docType data
#' @format The format is: num [1:98400] 65158 65176 65206 65194 65155 ...
#' @keywords datasets
#' @examples
#' 
#' ## load example data set
#' data(rockfall)
#' 
#' ## plot signal vector
#' plot(x = t, y = rockfall, type = "l")
#' 
"rockfall"

#' Time vector of a rockfall event.
#' 
#' The dataset comprises the time vector corresponding the to seismic signal
#' of the rockfall event from the example data set "rockfall".
#' 
#' @name t
#' @docType data
#' @format The format is: POSIXct[1:98400], format: "2015-04-06 13:16:54" ...
#' @keywords datasets
#' @examples
#' 
#' ## load example data set
#' data(rockfall)
#' 
"t"

#' Seismic traces of a small earthquake
#' 
#' The dataset comprises the seismic signal (all three components) of 
#' a small earthquake. The data have beenrecorded at 200 Hz sampling 
#' frequency with an Omnirecs Cube ext 3 data logger.
#' 
#' @name earthquake
#' @docType data
#' @format The format is: 
#' List of 3
#'  $ BHE: num [1:8001] -3.95e-07 ...
#'  $ BHN: num [1:8001] -2.02e-07 ...
#'  $ BHZ: num [1:8001] -1.65e-07 ...
#' @keywords datasets
#' @examples
#' 
#' ## load example data set
#' data(earthquake)
#' 
#' ## plot signal vector
#' plot(x = t, y = s$BHZ, type = "l")
#' 
"s"